@@ -2,7 +2,7 @@ package WebService::UrbanDictionary;
 
 # ABSTRACT: An OO interface to UrbanDictionary.com's JSON API.
 
-our $VERSION = "2.014";
+our $VERSION = "2.015";
 
 use Carp;
 use strict;
@@ -37,7 +37,7 @@ WebService::UrbanDictionary - An OO interface to UrbanDictionary.com's JSON API.
 
 =head1 VERSION
 
-version 2.014
+version 2.015
 
 =head1 SYNOPSIS
 
@@ -45,7 +45,7 @@ version 2.014
 
 	my $ud = WebService::UrbanDictionary->new;
 
-	my $results = request('perl'); 
+	my $results = $ud->request('perl'); 
 
 	for my $each (@{ $results->definitions }) {
 		printf "Definition: %s\n(by %s)\n\n", $each->definition, $each->author;
@@ -78,15 +78,29 @@ L<WWW::Search::UrbanDictionary> - Module for accessing UrbanDictionary's (deprec
 
 William Woodruff <william@tuffbizz.com>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Gabriel Vieira
+=for stopwords Gabriel Vieira Scott C William Woodruff
+
+=over 4
+
+=item *
 
 Gabriel Vieira <gabriel.vieira@gmail.com>
 
+=item *
+
+Scott C <cabrinhascott@gmail.com>
+
+=item *
+
+William Woodruff <woodruffw@users.noreply.github.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by William Woodruff.
+This software is Copyright (c) 2015 by William Woodruff.
 
 This is free software, licensed under:
 
