@@ -36,7 +36,7 @@ WebService::UrbanDictionary::Term - The Term object filled by WebService::UrbanD
 
 =head1 VERSION
 
-version 2.014
+version 2.015
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ version 2.014
 
 	my $ud = WebService::UrbanDictionary->new;
 
-	my $results = request('perl'); 
+	my $results = $ud->request('perl'); 
 
 	my $definition = $results->definition;
 
@@ -88,7 +88,7 @@ William Woodruff <william@tuffbizz.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by William Woodruff.
+This software is Copyright (c) 2015 by William Woodruff.
 
 This is free software, licensed under:
 
